==> nonebot_plugin_wakatime-0.2.1-py3-none-any.whl: nonebot_plugin_wakatime/render_pic.py <==
from datetime import datetime

from nonebot_plugin_htmlrender import template_to_pic, template_to_html

from .schema import WakaTime
from .config import RESOURCES_DIR, TEMPLATES_DIR, CustomSource, config
from .utils import image_to_base64, get_lolicon_image, calc_work_time_percentage


async def render(data: WakaTime) -> bytes:

    data["user"]["created_at"] = datetime.strptime(
        data["user"]["created_at"], "%Y-%m-%dT%H:%M:%SZ"
    ).strftime("%b %d %Y")

    default_background = RESOURCES_DIR / "images" / "background.png"

    match config.background_source:
        case "default":
            background_image = image_to_base64(default_background)
        case "LoliAPI":
            background_image = "https://www.loliapi.com/acg/pe/"
        case "Lolicon":
            background_image = await get_lolicon_image()
        case CustomSource() as cs:
            background_image = cs.to_uri()

    return await template_to_pic(
        template_path=str(TEMPLATES_DIR),
        template_name="profile.html",
        templates={
            "user": data["user"],
            "background_image": background_image,
            "insights": {
                "data": data["stats"],
                "last_week": calc_work_time_percentage(
                    data["stats"]["human_readable_total"]
                ),
                "daily_average": calc_work_time_percentage(
                    data["stats"]["human_readable_daily_average"], duration="day"
                ),
            },
            "operating_systems": data["stats"]["operating_systems"],
            "editors": data["stats"]["editors"],
            "languages": data["stats"]["languages"],
            "all_time_since_today": data["all_time_since_today"],
        },
        pages={
            "viewport": {"width": 550, "height": 10},
            "base_url": f"file://{TEMPLATES_DIR}",
        },
    )


async def render_bind_result(status_code: int, content: str) -> str:

    result = "success" if status_code == 200 else "error"

    return await template_to_html(
        template_path=str(TEMPLATES_DIR),
        template_name=f"{result}.html.jinja2",
        status_code=status_code,
        content=content,
    )

==> nonebot_plugin_wakatime-0.2.4-py3-none-any.whl: nonebot_plugin_wakatime/render_pic.py <==
from datetime import datetime

from nonebot_plugin_htmlrender import template_to_pic, template_to_html

from .schema import WakaTime
from .config import TEMPLATES_DIR
from .utils import calc_work_time_percentage


async def render(data: WakaTime) -> bytes:

    data["user"]["created_at"] = datetime.strptime(
        data["user"]["created_at"], "%Y-%m-%dT%H:%M:%SZ"
    ).strftime("%b %d %Y")

    return await template_to_pic(
        template_path=str(TEMPLATES_DIR),
        template_name="profile.html",
        templates={
            "user": data["user"],
            "background_image": data["background_image"],
            "insights": {
                "data": data["stats"],
                "last_week": calc_work_time_percentage(
                    data["stats"]["human_readable_total"]
                ),
                "daily_average": calc_work_time_percentage(
                    data["stats"]["human_readable_daily_average"], duration="day"
                ),
            },
            "operating_systems": data["stats"]["operating_systems"],
            "editors": data["stats"]["editors"],
            "languages": data["stats"]["languages"],
            "all_time_since_today": data["all_time_since_today"],
        },
        pages={
            "viewport": {"width": 550, "height": 10},
            "base_url": f"file://{TEMPLATES_DIR}",
        },
    )


async def render_bind_result(status_code: int, content: str) -> str:

    result = "success" if status_code == 200 else "error"

    return await template_to_html(
        template_path=str(TEMPLATES_DIR),
        template_name=f"{result}.html.jinja2",
        status_code=status_code,
        content=content,
    )
